@@ -7,7 +7,7 @@ int main()
     int a = inf.readInteger();
     int b = inf.readInteger();
 
-    int pattern = ouf.readLine();
+    int pattern = ouf.readInteger();
 
     if (a + b != pattern) {
         quitf(_wa, "expected %d, found %d", pattern, a + b);
